@@ -1,13 +1,8 @@
 import unittest
-import os
-import logging
 from datetime import datetime
 from pds_github_util.tags.tags import Tags
 from pds_github_util.utils.tokens import GITHUB_TOKEN
 
-logging.basicConfig(level=logging.DEBUG)
-logger = logging.getLogger(__name__)
-
 
 class MyTestCase(unittest.TestCase):
     def test_get_earliest_tag_after(self):
